@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::AccessControl;
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Mojo::Base 'Mojolicious::Plugin';
 use Net::CIDR::Lite;
@@ -12,38 +12,43 @@ use constant CONDITION_NAME => 'access';
 sub register {
     my ( $self, $app ) = @_;
 
-    $app->routes->add_condition( CONDITION_NAME() => sub {
-        my ( $r, $c, $cap, $args ) = @_;
-        $args ||= [];
+    $app->routes->add_condition(
+        CONDITION_NAME() => sub {
+            my ( $r, $c, $cap, $args ) = @_;
+            $args ||= [];
 
-        my $opt
-            = ( ref $args->[0] eq 'HASH' )
-            ? shift @$args
-            : {};
-        $opt->{cache} = 1 unless ( defined $opt->{cache} ); # enabled caches
+            my $opt
+                = ( ref $args->[0] eq 'HASH' )
+                ? shift @$args
+                : {};
 
-        if ( $opt->{on_deny} && ref $opt->{on_deny} ne 'CODE' ) {
-            Carp::croak "on_deny must be a CODEREF";
-        }
-
-        my $rules
-            = ( $opt->{cache} )
-            ? ( $r->{__PACKAGE__ . '._rules'} ||= $self->_rules(@$args) ) # caches to Mojolicious::Routes::Route
-            : $self->_rules(@$args);
-
-        for my $rule ( @$rules ) {
-            my ( $check, $allow ) = @{$rule};
-            my $result = $check->($c);
-            if ( defined $result && $result ) {
-                if ( !$allow && $opt->{on_deny} ) {
-                    $opt->{on_deny}->($c);
-                }
-                return $allow;
+            if ( $opt->{on_deny} && ref $opt->{on_deny} ne 'CODE' ) {
+                Carp::croak "on_deny must be a CODEREF";
             }
-        }
 
-        return 1;
-    } );
+            $opt->{cache} = 1 unless ( defined $opt->{cache} );
+            my $rules = ( $opt->{cache} )
+                ? ( $r->{ __PACKAGE__ . '._rules' } ||= $self->_rules(@$args) ) # caches to Mojolicious::Routes::Route
+                : $self->_rules(@$args);
+
+            for my $rule (@$rules) {
+                my ( $check, $allow ) = @{$rule};
+
+                my $result = $check->($c);
+                if ( defined $result && $result ) {
+
+                    # denied
+                    if ( !$allow && $opt->{on_deny} ) {
+                        $opt->{on_deny}->($c);
+                    }
+
+                    return $allow;
+                }
+            }
+
+            return 1;
+        }
+    );
 }
 
 sub _rules {
@@ -52,6 +57,7 @@ sub _rules {
     my @rules;
     for ( my $i = 0; $i < @args; $i += 2 ) {
         my ( $allowing, $rule ) = ( $args[$i], $args[ $i + 1 ] );
+
         Carp::croak "must be allow or deny"
             unless $allowing =~ /^(allow|deny)$/;
 
@@ -59,18 +65,19 @@ sub _rules {
         my $check = $rule;
 
         if ( $rule =~ /^ALL$/i ) {
-            $check = sub { 1 };
+            $check = sub {1};
         }
         elsif ( $rule =~ /[A-Z]$/i ) {
             $check = sub {
                 my $host = $_[0]->req->env->{'REMOTE_HOST'};
-                return unless defined $host; # skip
+                return unless defined $host;    # skip
                 return $host =~ /^(.*\.)?\Q${rule}\E$/;
             };
         }
         elsif ( ref($rule) ne 'CODE' ) {
             my $cidr = Net::CIDR::Lite->new();
             $cidr->add_any($rule);
+
             $check = sub {
                 my $addr = $_[0]->tx->remote_address;
                 if ( defined $addr ) {
@@ -101,7 +108,7 @@ Mojolicious::Plugin::AccessControl - Access control
     my $r = $self->routes;
     $r->get('/')->to('example#welcome')->over( 'access' => [
         allow => 'allowhost.com',
-        allow => '127.0.0.1'
+        allow => '127.0.0.1',
         allow => '192.168.0.3',
         deny  => '192.168.0.0/24',
         allow => sub { $_[0]->req->headers->user_agent =~ /Firefox/ },
@@ -155,7 +162,21 @@ Register condition in L<Mojolicious> application.
 
 =head1 ARGUMENTS
 
-'access' takes an arrayref of rules. Each rule consists of directive allow or deny and their argument. Rules are checked in the order of their record to the first match. Code rules always match if they return a defined non-zero value. Access is granted if no rule matched.
+  get '/' => ( 'access' => [
+      allow => 'allowhost.com',
+      allow => '127.0.0.1',
+      allow => '192.168.0.3',
+      deny  => '192.168.0.0/24',
+      allow => sub { $_[0]->req->headers->user_agent =~ /Firefox/ },
+      deny  => 'all',
+  ] ) => sub {
+      my $self = shift;
+      # do something
+  } => 'index';
+
+'access' takes an arrayref of rules.
+
+Each rule consists of directive allow or deny and their argument. Rules are checked in the order of their record to the first match. Code rules always match if they return a defined non-zero value. Access is granted if no rule matched.
 
 =over 2
 
@@ -189,11 +210,13 @@ this function takes Mojolicious::Controller as parameter. The rule is skipped if
 
   get '/only_local' => ( 'access' => [
       # options
-      { on_deny => sub {
-          my $self = shift; # Mojolicious::Controller
-          $self->res->code(403);
-          $self->render( text => 'Forbidden' );
-      } },
+      {
+        on_deny => sub {
+            my $self = shift; # Mojolicious::Controller
+            $self->res->code(403);
+            $self->render( text => 'Forbidden' );
+        },
+      },
       # rules
       allow => '127.0.0.1',
       deny  => 'all',
